eststo drop *
set matsize 1000
/*
    Main regressions on population density and settlement patterns
    Add covariates little by little
*/
forval i=0/2 {
    foreach v of global outcomes_ea_3 {
        reg_model "`v'"
        local method = r(method)
        local extras = r(extras)
        local limit  = r(limit)
        local add_regressor = r(add_regressor)
        
        qui `method' `v' $myreg ${EA`i'} `add_regressor' `extras', $cluster_ea `limit'
        qui eststo `v'_r`i'
        add_information fe "Continent" con "No" tim "No" weights "No"
        if strpos("$ols_regs", "`v'") {
            qui estadd scalar r2_p = e(r2)
        }

        if `i'==0 {
            add_information geo "No" ethnic "No"
            }
        if `i' == 1 {
            add_information geo "Yes" ethnic "No"
            }
        if `i'==2 {
            add_information geo "Yes" ethnic "Yes"

            qui local z : di %5.2f _b[$myreg]
            !echo "beta_`v'_basic,`z'" >> "${base_path}/Latex/exported_values.txt"

            /* When we use the most comprehensive specification, retrieve marginal effects
               and the most likely predicted level (together with its associated probability
            */
            qui levelsof `v' if e(sample), local(lvls)
            qui centile eclipses_log if e(sample), c(10 90)
            local c1 = r(c_1)
            local c2 = r(c_2)
            qui margins, at(eclipses_log == `c1')
            qui mat m = r(b)
            local num_levels : word count `lvls'
            local prob_1 = 0
            forval n=1/`num_levels' {
                if m[1,`n'] > `prob_1' {
                    local prob_1 : di %5.2f m[1,`n']
                    local likely_level_1 = `n'
                }
            }
            qui margins, at(eclipses_log == `c2')
            qui mat m = r(b)
            local prob_2 = 0
            forval n=1/`num_levels' {
                if m[1,`n'] > `prob_2' {
                    local prob_2 : di %5.2f m[1,`n']
                    local likely_level_2 = `n'
                }
            }
            /* Output the information to a txt file */
            !echo "likely_level_1_`v',`likely_level_1'" >>  "${base_path}/Latex/exported_values.txt"
            !echo "likely_level_1_prob_`v',`prob_1'" >> "${base_path}/Latex/exported_values.txt"
            !echo "likely_level_2_`v',`likely_level_2'" >>  "${base_path}/Latex/exported_values.txt"
            !echo "likely_level_2_prob_`v',`prob_2'" >>  "${base_path}/Latex/exported_values.txt"

            qui margins, dydx(eclipses_log)
            qui mat b = r(b)
            qui estpost tabulate `v' if e(sample)
            qui mat x = e(pct)
            foreach lvl of local lvls {
                local z   : di %5.2f b[1, `lvl']*100
                local pct : di %5.2f x[1, `lvl']

                /* Output the information to a txt file */
                !echo "margin_`v'_`mgf'_`lvl',`z'" >> "${base_path}/Latex/exported_values.txt"
                !echo "pct_`v'_`lvl',`pct'" >> "${base_path}/Latex/exported_values.txt"
                }
            }

        }
    }

/* Compute correlation between V30 and V31 */
qui reg v30 v31 $EA2 eclipses_log
qui corr v30 v31 if e(sample)
local z : di %5.2f r(rho)
!echo "corr_v30_v31,`z'" >> "${base_path}/Latex/exported_values.txt"


/* Repeat the main regressions including high gods as regressor */
foreach v of global outcomes_ea_3 {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)

    qui `method' `v' $myreg ${EA2} i.v34 `add_regressor' `extras', $cluster_ea `limit'
    qui eststo gods_`v'
    add_information fe "Continent" con "No" weights "No" tim "No" geo "Yes" ethnic "Yes"
    if strpos("$ols_regs", "`v'") {
        qui estadd scalar r2_p = e(r2)
    }
}

/*
    For the remaining variables in the Ethnographic Atlas we run
    the regressions using all the covariates
*/
foreach v of global outcomes_ea_1 {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)
    
    qui `method' `v' $myreg $EA2 `regressor' `add_regressor' `extras', $cluster_ea `limit'
    qui eststo `v'
    add_information fe "Continent" con "No" tim "No" weights "No" geo "Yes" ethnic "Yes"
    if strpos("$ols_regs", "`v'") {
        estadd scalar r2_p = e(r2)
    }

    /* Retrieve marginal effects and the most likely predicted level 
       (together with its associated probability.
       We use different techniques depending on the regression method
    */

    /* Ordered probit: we compute the most likely level and probability */
    if strpos("$oprobit_regs", "`v'") {
        qui local z : di %5.2f _b[$myreg]
        /* Output the information to a txt file */
        !echo "beta_`v'_basic,`z'" >> "${base_path}/Latex/exported_values.txt"

        qui levelsof `v' if e(sample), local(lvls)
        qui centile eclipses_log if e(sample), c(10 90)
        local c1 = r(c_1)
        local c2 = r(c_2)
        qui margins, at(eclipses_log == `c1')
        qui mat m = r(b)
        local num_levels : word count `lvls'
        local prob_1 = 0
        forval n=1/`num_levels' {
            if m[1,`n'] > `prob_1' {
                local prob_1 : di %5.2f m[1,`n']
                local likely_level_1 = `n'
            }
        }
        qui margins, at(eclipses_log == `c2')
        qui mat m = r(b)
        local prob_2 = 0
        forval n=1/`num_levels' {
            if m[1,`n'] > `prob_2' {
                local prob_2 : di %5.2f m[1,`n']
                local likely_level_2 = `n'
            }
        }
        /* Output the information to a txt file */
        !echo "likely_level_1_`v',`likely_level_1'" >>  "${base_path}/Latex/exported_values.txt"
        !echo "likely_level_1_prob_`v',`prob_1'" >> "${base_path}/Latex/exported_values.txt"
        !echo "likely_level_2_`v',`likely_level_2'" >>  "${base_path}/Latex/exported_values.txt"
        !echo "likely_level_2_prob_`v',`prob_2'" >>  "${base_path}/Latex/exported_values.txt"

        qui margins, dydx(eclipses_log)
        qui mat b = r(b)
        foreach lvl of local lvls {
            local z : di %5.2f b[1, `lvl']*100
            /* Output the information to a txt file */
            !echo "margin_`v'_`mgf'_`lvl',`z'" >> "${base_path}/Latex/exported_values.txt"
            }

        qui estpost tabulate `v' if e(sample)
        qui mat x = e(pct)
        foreach lvl of local lvls {
            local z : di %5.2f x[1, `lvl']
            /* Output the information to a txt file */
            !echo "pct_`v'_`lvl',`z'" >> "${base_path}/Latex/exported_values.txt"
        }
    }

    /* Negative binomial: compute the predicted number of tasks */
    if strpos("$nbreg_regs", "`v'") {
        qui local z : di %5.2f _b[$myreg]
        !echo "beta_`v'_basic,`z'" >> "${base_path}/Latex/exported_values.txt"
        qui centile eclipses_log if e(sample), c(10 90)
        local c1 = r(c_1)
        local c2 = r(c_2)
        qui margins, at(eclipses_log == `c1' eclipses_log == `c2')
        qui mat m = r(b)
        local pred_number_1 : di %5.2f m[1,1]
        local pred_number_2 : di %5.2f m[1,2]

        /* Output the information to a txt file */
        !echo "pred_number_1_`v',`pred_number_1'" >>  "${base_path}/Latex/exported_values.txt"
        !echo "pred_number_2_`v',`pred_number_2'" >>  "${base_path}/Latex/exported_values.txt"

        qui margin, dydx(eclipses_log) 
        qui mat b = r(b)
        local z : di %5.2f b[1, 1]

        /* Output the information to a txt file */
        !echo "margin_`v'_`mgf',`z'" >> "${base_path}/Latex/exported_values.txt"

        qui sum `v' if e(sample)
        local z : di %5.2f r(mean)

        /* Output the information to a txt file */
        !echo "pct_`v'_`lvl',`z'" >> "${base_path}/Latex/exported_values.txt"
    }

    /* OLS model: retrieve the coefficients */
    if strpos("$ols_regs", "`v'") {
        qui local z : di %5.2f _b[$myreg]

        /* Output the information to a txt file */
        !echo "beta_`v'_basic,`z'" >> "${base_path}/Latex/exported_values.txt"
        qui sum `v' if e(sample)
        qui local z : di %5.2f r(mean)

        /* Output the information to a txt file */
        !echo "pct_`v'_basic,`z'" >> "${base_path}/Latex/exported_values.txt"
    }

}

/*
    Regressions using the folklore data
    These incorporate additional regressors that we keep
    in the `add_regressor' local.
*/
foreach v of global outcomes_folklore {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)

    qui `method' `v' eclipses_log $EA2 `add_regressor', $cluster_ea
    qui eststo `v'
    add_information fe "Continent" con "No" weights "No" tim "No" geo "Yes" ethnic "Yes"

    if strpos("$ols_regs", "`v'") {
        qui estadd scalar r2_p = e(r2)
    }

    /* Compute the marginal effects and the predicted number of archetypes */
    qui centile eclipses_log if e(sample), c(10 90)
    local c1 = r(c_1)
    local c2 = r(c_2)
    qui margins, at(eclipses_log == `c1' eclipses_log == `c2')
    qui mat m = r(b)
    local pred_number_1 : di %5.2f m[1,1]
    local pred_number_2 : di %5.2f m[1,2]

    /* Output the information to a txt file */
    !echo "pred_number_1_`v',`pred_number_1'" >>  "${base_path}/Latex/exported_values.txt"
    !echo "pred_number_2_`v',`pred_number_2'" >>  "${base_path}/Latex/exported_values.txt"

    qui margins, dydx(eclipses_log)
    qui mat b = r(b)
    local z : di %5.2f b[1, 1]

    /* Output the information to a txt file */
    !echo "margin_`v'_`mgf',`z'" >> "${base_path}/Latex/exported_values.txt"

    qui sum `v' if e(sample)
    local z : di %5.2f r(mean)

    /* Output the information to a txt file */
    !echo "pct_`v',`z'" >> "${base_path}/Latex/exported_values.txt"
    qui local z : di %5.2f _b[eclipses_log]

    /* Output the information to a txt file */
    !echo "beta_`v'_basic,`z'" >> "${base_path}/Latex/exported_values.txt"
}

/* Regress high gods on eclipses */
foreach v in v34 {
    qui oprobit `v' eclipses_log $EA2, $cluster_ea
    qui eststo `v'
    add_information fe "Continent" con "No" tim "No" weights "No" geo "Yes" ethnic "Yes"
    qui estadd scalar myr2 = e(r2_p)
}
