/* Regressions considering the effect of area */

/*
    Drop the top and bottom 5%
    Note that the ethnic groups to be dropped change with the 
    dependent variable
*/
foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)

    /* First regression, to determine the observation we use and discard the top/bottom 5% */
    qui `method' `v' $myreg $EA2 `add_regressor' `extras', $cluster_ea `limit'

    preserve
    qui capture drop to_drop
    qui xtile to_drop = area_km if e(sample), nq(20)
    qui drop if to_drop == 1
    qui drop if to_drop == 20
    qui `method' `v' $myreg $EA2 `add_regressor' `extras', $cluster_ea `limit'
    restore
    qui eststo `v'_area_1
    add_information fe "Continent" con "No" tim "No" geo "Yes" ethnic "Yes"

    if strpos("$ols_regs", "`v'") {
        estadd scalar r2_p = e(r2)
    }
}

/*
    Create k-means and use these as fixed effects
*/
global todrop_var i.tile_area
global myx_area : list global(EA2) - global(todrop_var)

foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)
    
    preserve
    qui `method' `v' $myreg $myx_area `add_regressor' `extras', $cluster_ea `limit'
    qui cluster kmeans area_km if e(sample), k(10) gen(kmean)
    qui `method' `v' $myreg $myx_area i.kmean `add_regressor' `extras', $cluster_ea `limit'
    restore
    qui eststo `v'_area_2
    add_information fe "Continent" con "No" tim "No" geo "Yes" ethnic "Yes"

    if strpos("$ols_regs", "`v'") {
        estadd scalar r2_p = e(r2)
    }
}

/*
    Use area as regressor
*/
foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)
    
    qui `method' `v' $myreg $EA2 area_km `add_regressor' `extras', $cluster_ea `limit'
    qui eststo `v'_area_3
    add_information fe "Continent" con "No" tim "No" geo "Yes" ethnic "Yes"

    if strpos("$ols_regs", "`v'") {
        estadd scalar r2_p = e(r2)
    }
}

/*
    Use a third-degree polynomial of area as regressor
*/
foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)
    
    qui `method' `v' $myreg $EA2 c.area_km##c.area_km##c.area_km `add_regressor' `extras', $cluster_ea `limit'
    qui eststo `v'_area_4
    add_information fe "Continent" con "No" tim "No" geo "Yes" ethnic "Yes"

    if strpos("$ols_regs", "`v'") {
        estadd scalar r2_p = e(r2)
    }
}

* Regressions including eclipses/area as additional regressor
* To avoid endogeneity, these regressions must control for the number of eclipses and area
/*
    Use the number of eclipses per unit of area as regressor.
    To avoid endogeneity, this regression should also control for area and the number of eclipses
    We create these variables.

    To gauge the effect of solar eclipses, we compute the marginal effect they have.
*/
qui capture drop n_eclipses
qui capture drop inv_area
qui gen n_eclipses = exp(eclipses_log)/35 /* Divide by 35, nicer coefficients */
qui gen inv_area = 1/area_km          /* The inverse of area */

foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)

    qui `method' `v' c.n_eclipses#c.inv_area n_eclipses area_km $EA2 `add_regressor' `extras', $cluster_ea `limit'
    qui eststo `v'_int
    add_information fe "Continent" geo "Yes" ethnic "Yes"

    if strpos("$ols_regs", "`v'") {
        qui estadd scalar r2_p = e(r2)
    }
    qui margins, dydx(n_eclipses) post
    qui eststo `v'_margin
    qui sum `v' if e(sample)
    estadd scalar avg = r(mean)
    estadd scalar std = r(sd)
}
