cd "$path_data"

clear
import delimited "geography.csv"
tempfile geography
save `geography', replace

clear
import delimited "calories_centroids.csv"
tempfile calories
save `calories', replace

clear
import delimited "distance_river_coast_volcano_tectonic.csv"
rename in_ea navn
tempfile distance_r_c_v_t
save `distance_r_c_v_t', replace

clear
import delimited "distance_addis_km.csv"
tempfile distance_addis_km
save `distance_addis_km', replace

clear
import delimited "technology.csv"
tempfile technology
gen navn = upper(society)
/* Manually modify names to increase matches */
replace navn = "WADADOKAD"	if navn == "WADADOKADO"
replace navn = "NAMBICUAR"	if navn == "NAMBICURA"
replace navn = "MONTAGNAI"	if navn == "MONTAGNAIS"
replace navn = "NSAULTEA" 	if navn == "NORTHERN SAULTEAUX"
replace navn = "CHIRICAHU"	if navn == "CHIRICAHUA"
replace navn = "EPOMO"    	if navn == "EASTERN POMO"
replace navn = "YOKUTS"   	if navn == "LAKE YOKUTS"
replace navn = "HATSA"    	if navn == "HATSA KINDIGA"
replace navn = "NEGRISEMB"	if navn == "NEGRI SEMBILAN"
replace navn = "TROBRIAND"	if navn == "TROBRIANDS"
replace navn = "TOBELORES"	if navn == "TOBELORESE"
replace navn = "GROSVENTR"	if navn == "GROS VENTRE"
replace navn = "BELLACOOL"	if navn == "BELLACOOLA"
replace navn = "MARQUESAN"	if navn == "MARQUESANS"
replace navn = "RAMCOCAME"	if navn == "RAMCOCAMECRA"
replace navn = "MARSHALLE"	if navn == "MARSHALLESE"
replace navn = "NICOBARES"	if navn == "NICOBARESE"
replace navn = "MURIAGOND"	if navn == "MARIA GOND"
replace navn = "ZAZZAGAWA"	if navn == "ZAZZAGAWA HAUSA"

save `technology', replace

clear
import delimited "dplace.csv"
tempfile dplace
save `dplace', replace

clear
import delimited "eclipse_stats_-2000_1500.csv"

rename in_ea navn
tempfile eclipse_stats__2000_1500
save `eclipse_stats__2000_1500"', replace

clear
import delimited "external_data.csv"
tempfile external_data
save `external_data', replace

clear
import delimited "eclipse_stats_500_years.csv"
rename in_ea navn

rename total_ec__2000_1500  total_ec_2000BC_1500BC
rename total_ec__1500_1000  total_ec_1500BC_1000BC
rename total_ec__1000_500   total_ec_1000BC_500BC
rename total_ec__500_0      total_ec_500BC_0
rename total_ec__0_500      total_ec_0_500
rename total_ec__500_1000   total_ec_500_1000
rename total_ec__1000_1500  total_ec_1000_1500
rename total_ec__1900_2000  total_ec_1900_2000
tempfile eclipse_stats_500_years
save `eclipse_stats_500_years', replace

clear
import delimited "EA.csv"
rename v138 longitude
gen group = lower(navn)

* Some manual fixes to match rare cases
replace group = "coeurd'al" if group=="coeurdal"
duplicates drop group, force

gen in_ea = navn
merge 1:1 navn using `eclipse_stats__2000_1500', gen(_eclipses)
drop if _eclipses == 2

merge 1:1 navn using `eclipse_stats_500_years', gen(_eclipse_stats)
drop if _eclipse_stats == 2

merge 1:1 navn using `external_data', gen(_External)
gen area_km_log = log(area_km)

* Import Fenske data
drop if missing(group)
merge 1:1 group using `geography', gen(_Geography) keepusing(rugavg elevavg malaravg)
drop if _Geography==2

encode continent, gen(cont_enc)
encode mhtname, gen(mht_enc)
replace mht_enc = . if mhtname ==""

* Generate play strategy games
gen strategy = 1 if v35 == 4 | v35== 6 | v35 == 8
replace strategy = 0 if missing(strategy)&!missing(v35)

* Import distances to Addis in km
drop if navn == ""
merge 1:1 navn using `distance_addis_km', keepusing(distance_addis_km) gen(_dist_Addis_km)
drop if _dist_Addis_km == 2
drop if missing(navn)

gen distance_coast_km = distance/1000
drop if missing(navn)
* Add technology
merge 1:1 navn using `technology', keepusing(technology) gen(_SCCS_Technology)
pause
drop if _SCCS_Technology == 2
replace technology = log(technology)

* SCCS dplace
merge 1:1 navn using `dplace"', gen(_dplace) force

merge 1:1 navn using `distance_r_c_v_t', ///
	keepusing(distance_*) gen(_Riv_Coast_Volc_Tec)
drop if _Riv_Coast_Volc_Tec == 2

* Increase the number of matches
replace navn = "PL TONGA" if navn == "PLTONGA"
duplicates drop navn, force
merge 1:1 navn using `calories', keepusing(calavg fenske_latitude fenske_longitude) gen(_Fenske)

replace v34=. if v34==0

drop lati longitude
rename fenske_latitude latitude
rename fenske_longitude longitude

gen writing = . /* Alternative coding for writing */
replace writing = 0 if sccs149 == 0
replace writing = 0 if sccs149 == 1
replace writing = 0 if sccs149 == 2
replace writing = 1 if sccs149 == 3
replace writing = 1 if sccs149 == 4

foreach v of varlist distance_river_km distance_addis_km distance_tectonic_km distance_volcano_km {
    replace `v' = `v'/1000
}
foreach v of varlist distance_coast_km distance_river_km distance_addis_km distance_tectonic_km distance_volcano_km {
    gen `v'_log = log(`v')
}

* Fix latitude for some islands
replace latitude= -1.667504 if navn=="AUA"
replace latitude= 15.875998 if navn=="CAROLINIA"
replace latitude= 13.939253 if navn=="CHAMORRO"
replace latitude=-14.321610 if navn=="FUTUNANS"
replace latitude=  7.364070 if navn=="IFALUK"
replace latitude=  1.090050 if navn=="KAPINGAMA"
replace latitude=  5.315720 if navn=="KUSAIANS"
replace latitude=-23.115573 if navn=="MANGAREVA"
replace latitude=-10.180507 if navn=="MANIHIKIA"
replace latitude= -9.385833 if navn=="MARQUESAN"
replace latitude=  7.432316 if navn=="MARSHALLE"
replace latitude= -9.722425 if navn=="MIRIAM"
replace latitude=-13.817256 if navn=="MOTA"
replace latitude= -9.451414 if navn=="MOTU"
replace latitude=-19.049451 if navn=="NIUEANS"
replace latitude= -0.045579 if navn=="ONOTOA"
replace latitude=  7.411915 if navn=="PALAUANS"
replace latitude=-20.713328 if navn=="RAROIANS"
replace latitude=-12.505108 if navn=="ROTUMANS"
replace latitude=-16.510351 if navn=="SENIANG"
replace latitude=-17.355240 if navn=="TAHITIANS"
replace latitude=-12.275475 if navn=="TIKOPIA"
replace latitude= -9.079014 if navn=="TOKELAU"
replace latitude= -9.008585 if navn=="TONGAREVA"
replace latitude=-38.491390 if navn=="TRISTAN"
replace latitude=  7.365039 if navn=="TRUKESE"
replace latitude=  9.134178 if navn=="ULITHIANS"
replace latitude=-13.758268 if navn=="UPOLU"
replace latitude= -4.113953 if navn=="USIAI"
replace latitude=-13.274017 if navn=="UVEANS"
replace latitude= -3.232395 if navn=="WOGEO"
replace latitude=  9.556413 if navn=="YAPESE"

* Fix calories for some islands
replace calavg=2499.834400  if navn=="AUA"
replace calavg=2658.494995  if navn=="CAROLINIA"
replace calavg=2681.382467  if navn=="CHAMORRO"
replace calavg=2431.754886  if navn=="FUTUNANS"
replace calavg=2807.953125  if navn=="IFALUK"
replace calavg=2667.029785  if navn=="KAPINGAMA"
replace calavg=2439.256592  if navn=="KUSAIANS"
replace calavg=1384.074987  if navn=="MANGAREVA"
replace calavg=2599.825849  if navn=="MANIHIKIA"
replace calavg=2405.591654  if navn=="MARQUESAN"
replace calavg=2497.243837  if navn=="MARSHALLE"
replace calavg=1183.446744  if navn=="MIRIAM"
replace calavg=1183.300049  if navn=="MOTA"
replace calavg=3096.293530  if navn=="MOTU"
replace calavg=2262.468994  if navn=="NIUEANS"
replace calavg=2624.624084  if navn=="ONOTOA"
replace calavg=2564.243286  if navn=="PALAUANS"
replace calavg=3027.346558  if navn=="RAROIANS"
replace calavg=3051.665869  if navn=="ROTUMANS"
replace calavg=2926.691077  if navn=="SENIANG"
replace calavg=1515.535618  if navn=="TAHITIANS"
replace calavg=2616.503174  if navn=="TIKOPIA"
replace calavg=2361.226565  if navn=="TOKELAU"
replace calavg=2743.235682  if navn=="TONGAREVA"
replace calavg= 837.757050  if navn=="TRISTAN"
replace calavg=2282.551025  if navn=="TRUKESE"
replace calavg=2789.346680  if navn=="ULITHIANS"
replace calavg=2211.121273  if navn=="UPOLU"
replace calavg=1193.221294  if navn=="USIAI"
replace calavg=2319.708916  if navn=="UVEANS"
replace calavg=2340.376709  if navn=="WOGEO"
replace calavg=2508.846680  if navn=="YAPESE"

gen abs_lat = abs(latitude)
* South dummy
gen south = (latitude < 0)

* Have area in km sq.
replace area_km =area_km / 100^2

duplicates drop navn, force	

* Import data from Stelios Folklore
rename navn atlas
replace atlas = "COEURD'AL" if atlas == "COEURDAL"
merge 1:1 atlas using "motifs_ea_groups.dta", keepusing(a12* a14 a15) gen(_eclipses_stelios)

* Generate indicator for the understanding of eclipses using Stelios matches
egen    explanation = rowtotal(a12*)
replace explanation = 1 if explanation > 0 & !missing(explanation)
replace explanation = . if missing(a12a)
replace explanation = 2 if a14 == 1
replace explanation = 2 if a15 == 1

* Import motifs according to ConceptNet
merge 1:1 atlas using "concept_frequencies_ea_groups.dta", keepusing($motifs $motifs_religion motifs_total nmbr_title year_firstpub) gen(_eclipse_concept)

* Import the words we use as controls
foreach v in $motifs $motifs_religion {
    if strpos("$folklore_controls", "`v'") {
        * The global folklore_controls has the original variable and, next to it, the control, thus we add one to the position
        local motif_position : list posof "`v'" in global(folklore_controls)
        local motif_position = `motif_position' + 1
        local control : word `motif_position' of $folklore_controls
        merge 1:1 atlas using "concept_frequencies_ea_groups.dta", keepusing(`control') nogen
    }
}

* Convert variables from Folklore to ratio
foreach v of varlist $motifs $motifs_religion {
    gen share_`v' = `v' / motifs_total
}

* Purple_related and religion_related have many zeros, convert to binary
replace purple_related = (purple_related > 0)
replace religion_related = (religion_related > 0)

gen lnnmbr_title = log(nmbr_title)
gen lnyear_firstpub = log(year_firstpub)
gen lnmotifs_total = log(motifs_total)

* Compute the number of tasks
capture drop total_tasks
capture drop tasks_with_info
capture drop share_tasks
gen tasks = .
gen tasks_with_info = .
foreach v of varlist v44-v49 {
    replace tasks = 0 if !missing(`v')&`v'<9&tasks == .
    replace tasks_with_info = 0 if !missing(`v')&tasks_with_info == .
    replace tasks = tasks + 1 if !missing(`v')&`v'<9
    replace tasks_with_info = tasks_with_info + 1 if !missing(`v')
    }
gen share_tasks = tasks / tasks_with_info
xtile tile_area = $area, nq(10)
gen eclipses_log = log(eclipses)
gen eclipses_lunar_log = log(eclipses_lunar)

* Add one to eclipse explanation (ordered probit, does not change the results) to compute more easiliy the marginal effects
replace explanation = explanation + 1 if !missing(explanation)

* Some ethnic groups have no data on lightning, put it to zero
replace lightning = 0 if missing(lightning)
replace lightning = log(1 + lightning)
replace clouds = log(1 + clouds)

preserve
local z
foreach v in $EA2 $outcomes_ea_3 $outcomes_ea_1 eclipses_log $motifs {
    if strpos("`v'", ".") {
        local tmp = substr("`v'", 3, .)
        local z "`z' `tmp'"
        }
    else {
        local z "`z' `v'"
        }
    }
keep `z'
save "$path_data/database_plot_ea.dta", replace
restore

drop sccs*
gen sortid = _n 
