* Add lunar eclipses as an additional regressor
forval i=0/1 {
    if `i' == 0 {
        local variables "eclipses_lunar_log"
        }
    if `i' == 1 {
        local variables "eclipses_log eclipses_lunar_log"
        }
    foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
        reg_model "`v'"
        local method = r(method)
        local extras = r(extras)
        local limit  = r(limit)
        local add_regressor = r(add_regressor)
        
        qui `method' `v' `variables' $EA2 `add_regressor' `extras', $cluster_ea `limit'
        qui eststo `v'_rob_`i'
        add_information fe "Continent" con "No" tim "No" geo "Yes" ethnic "Yes" weights "No"

        if strpos("$ols_regs", "`v'") {
            estadd scalar r2_p = e(r2)
        }
    }
}

* Use the percentage of tales as dependent variable
* Now, instead of count data we use a percentage.
* Therefore, insteado of poisson we shall use fracreg with a logit link
foreach v in $main_folklore {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)

    /* Instead of poission regression, use fracreg */
    if strpos("$poisson_regs", "`v'") {
        local method "fracreg logit"
        local limit "iter(100)"
    }

    qui `method' share_`v' eclipses_log $EA2 `add_regressor', $cluster_ea `limit'
    qui eststo f_`v'
    add_information fe "Continent" geo "Yes" ethnic "Yes"
}

* Quantile regressions
* The regressions for eclipse explanation and games of strategy do not converge
global q_tables ""
foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
    reg_model "`v'"
    local extras = r(extras)
    local add_regressor = r(add_regressor)

    capture bsqreg `v' $myreg $EA2 `add_regressor' `extras'
    /* Only proceed if the regression has converged
       We add the outcomes that had converged to the global `q_tables` to simplify generating the table later on */
    if e(convcode) == 0 {
        qui eststo q_`v'
        add_information fe "Continent" geo "Yes" ethnic "Yes"
	global q_tables "${q_tables} q_`v'"
    }
}

/* Repeat the main analysis dropping one continent at a time */
qui capture drop cont_enc2
qui encode continent, gen(cont_enc2)
qui levelsof cont_enc2, local(continents)
foreach c of local continents {
    foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
        reg_model "`v'"
        local method = r(method)
        local extras = r(extras)
        local limit  = r(limit)
        local add_regressor = r(add_regressor)

        preserve
        qui drop if  cont_enc2 == `c'
        qui `method' `v' $myreg $EA2 `add_regressor' `extras', $cluster_ea `limit'

        /* Only store the regression if it converged (or if we ran an OLS, which always converges */
        if e(converged) | strpos("$ols_regs", "`v'") {
            eststo `v'_c_`c' 
        }
        restore
    }
}

/* First, we plot the variables that appear in the Ethnographic Atlas */
local mycoef ""
foreach c of local continents {
    local mycoef "`mycoef' ("
    foreach v in $outcomes_ea_3 $outcomes_ea_1 {
        local mycoef "`mycoef' `v'_c_`c', aseq(`v') \"
    }
    local mycoef "`mycoef' )"
}

/* Binned scatterplots illustrating the relationship between area
   and the probability of having a low number of solar eclipses

   Because all ethnic groups see, at least, one solar eclipse, 
   we consider that ethnic groups with 10, 25, ..., 150 solar eclipses had none
   This part of the script requires the `binsreg` command by Cattaneo
   net install binsreg, from(https://raw.githubusercontent.com/nppackages/binsreg/master/stata) replace
*/

foreach i in 10 25 50 100 150 { 
    sort eclipses_log sortid
    capture drop no_eclipses
    gen no_eclipses = .
    replace no_eclipses = 1 in 1/`i'
    replace no_eclipses = 0 if missing(no_eclipses)

    /* Results including the full set of covariates */
    binscatter no_eclipses area_km_log, controls(${EA2}) line(qfit) xtitle("log(area)") ytitle("Zero eclipses") colors(black)
    graph export "${path_figures}/Robustness/binsreg_multivariate_`i'.pdf", as(pdf) name("Graph") replace

    /* Results including only area as regressor */
    binscatter no_eclipses area_km_log, line(qfit) xtitle("log(area)") ytitle("Zero eclipses") colors(black)
    graph export "${path_figures}/Robustness/binsreg_bivariate_`i'.pdf", as(pdf) name("Graph") replace
}

/* To further disentangle the effect of solar eclipses from that of ethnic homeland surface
   we predict the number of solar eclipses as a function of area and use the prediction
   as the main regressor in regressions following the baseline model.
   We repeat the procedure 100 times.
   If area is the driving force behind the results, we should obtain a distribution of coefficients
   close to the actual coefficient associated to solar eclipses.
   Because this exercise also generates an attenuation bias, we also draw the number of eclipses
   from a distribution centered around the actual number of eclipses, so that it embodies the
   attenuation bias but is, otherwise, true to the actual number of solar eclipses
*/
sort sortid
qui set seed 1111
qui capture drop n_eclipses
qui gen n_eclipses = exp(eclipses_log)
foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
    capture drop coef_`v'      /* Coefficient corresponding to predicted solar eclipses */
    capture drop att_`v'       /* Coefficient when predictions only embody an attenuation bias */
    capture drop corr_ec_random /* Variable to track the correlation between the predicted eclipses and the actual ones */
    qui gen coef_`v' = .
    qui gen att_`v' = .
    qui gen corr_ec_random = .
}

forval i=1/100 {
    di "`i'"
    /* Regression to predict number of eclipses with added noise */
    capture drop random
    capture drop attenuation
    qui poisson n_eclipses area_km_log
    qui predict random
    qui replace random = log(rpoisson(random))
    qui gen attenuation = log(rpoisson(n_eclipses))
    qui corr eclipses_log random
    qui replace corr_ec_random = r(rho) in `i'

    foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
        reg_model "`v'"
        local method = r(method)
        local extras = r(extras)
        local limit  = r(limit)
        local add_regressor = r(add_regressor)
        
        /* Regression using the random number of solar eclipses */
        qui `method' `v' random $EA2 `addvar' `extras', $cluster_ea `limit'
        qui replace coef_`v' = _b[random] in `i'

        /* Regression focusing on the attenuation bias */
        qui `method' `v' attenuation $EA2 `addvar' `extras', $cluster_ea `limit' `asis'
        qui replace att_`v' = _b[attenuation] in `i'
    }
}

foreach v in $outcomes_ea_3 $outcomes_ea_1 $main_folklore {
    reg_model "`v'"
    local method = r(method)
    local extras = r(extras)
    local limit  = r(limit)
    local add_regressor = r(add_regressor)
   
    /* Obtain the true coefficient */
    qui `method' `v' eclipses_log $EA2 `add_regressor' `extras', $cluster_ea `limit'
    qui local true_coef = _b[eclipses_log] 

    /* Plot the distribution of coefficients for the random eclipses and the attenuation bias
       We use `addplot` to extend the x-axis as to reach the position of the `vline`
    */
    qui local max_x  = `true_coef' * 1.2
    qui twoway (kdensity coef_`v', lcolor(black) lpattern(dash)) (kdensity att_`v', lcolor(black) lpattern(dot) xline(`true_coef', lcolor(black))) (pci 0 0 0 `max_x', lcolor(none)), xtitle("Random eclipses") legend(order(1 "Predicted eclipses" 2 "Attenuation bias"))
    qui translate @Graph "${path_figures}/Random_Eclipses_`v'.pdf", name("Graph")
}
