global ashraf_years "-2000_0 -2000_1000"

/* Import country volcanoes */
clear
import delimited "$path_data/volcanoes_countries.csv"
rename iso3 code
tempfile volcanoes_countries
save "volcanoes_countries", replace

/* Import eclipses (solar and lunar) at the country level */
foreach year of global ashraf_years {
    clear
    import delimited "$path_data/eclipses_countries_`year'.csv"
    rename iso3 code
    local y = subinstr("`year'", "-", "_", .)
    keep code total_ec_`y' total_ec_lunar_*
    tempfile eclipses_countries_`y'
    save "eclipses_countries_`y'", replace
    }

/* Basic data on technology from Ashraf and Galor, 2011 */
clear
use "$path_data/Ashraf_Galor__2011.dta"
foreach year of global ashraf_years {
    local y = subinstr("`year'", "-", "_", .)
    merge 1:1 code using "eclipses_countries_`y'", gen(_eclipses_`y')
    }

merge 1:1 code using "volcanoes_countries", gen(_volc)

/* Rename variables so that we can more easily loop through them */
rename ln_CEtech1K ln_CEtech_1000
rename ln_CEtech0 ln_CEtech_0
rename ln_CITtech0 ln_CITtech_0
rename ln_CITtech1K ln_CITtech_1000
rename ln_comm0 ln_comm_0
rename ln_trans0 ln_trans_0
rename ln_indus0 ln_indus_0
rename ln_indus1K ln_indus_1000
rename ln_comm1K ln_comm_1000
rename ln_trans1K ln_trans_1000
rename total_ec__2000_0 ec_0
rename total_ec__2000_1000 ec_1000
rename total_ec_lunar_2000_0 ec_lunar_0
rename total_ec_lunar_2000_1000 ec_lunar_1000

drop if missing(country)
keep ln_trans_* ln_comm_* ln_indus_* ln_CE* ln_CI* country ec_* volcanoes_*
reshape long ln_comm_ ln_indus_ ln_trans_ ln_CEtech_ ln_CITtech_ ec_ ec_lunar_ volcanoes_, i(country) j(year)

encode country, gen(cc)
drop country
rename cc country
xtset country year, delta(1000)

gen lec = log(ec_)
gen lec_lunar = log(ec_lunar_)
gen lvo = log(1 + volcanoes_)

/*
    Run a tobit regression, with lower bound 0 and upper bound log(2).
    we do so because the variables can only take values between these
    We first use lunar eclipses and then both solar and lunar.
*/
forval i=0/1 {
    if `i' == 0 {
        local variables "lec_lunar"
    }
    if `i' == 1 {
        local variables "lec lec_lunar"
    }
    foreach v of varlist ln_* {
        qui xttobit `v' `variables' lvo, ll(0) ul(log(2))
        qui eststo `v'_rob_`i'
        add_information fe "Country" tim "Yes" con "No" ethnic "No" geo "No"
    }
}
