do "$path_stata/5-Wikipedia_Preparation.do"
set scheme s2mono

/* 
    Regressions with two sets of weights
*/
foreach v of global outcomes_wikipedia {
    forval i=1/2 {
        qui reghdfe `v' eclipses_binary volcanoes_binary [pw=weight_`i'], absorb(country century) cluster(country#century)
        qui eststo `v'_`i'
        add_information fe "City" tim "Yes" geo "No" ethnic "No"
        qui estadd scalar r2_p = e(r2)
        if `i' == 1 {
            add_information weights "Sample"
        }
        if `i' == 2 {
            add_information weights "Population"
        }
        qui sum `v' if e(sample)
        local z : di %5.2f r(mean)*100
        !echo "pct_`v'_`i',`z'" >> "${base_path}/Latex/exported_values.txt"
        qui local z : di %5.2f _b[eclipses_binary]*100
        !echo "beta_`v'_`i',`z'" >> "${base_path}/Latex/exported_values.txt"
    }
}

/*
    The cumulative effect over time
    Note that we expand the sample little by little.
    Thus, because there are more people in modern times, the weight of more
    recent cohorts increases, biasing the results towards the effect of solar
    eclipses on these more modern people.
*/
global regs_to_plot "("
global myeqrename ""
qui levelsof century, local(cen)
foreach c of local cen {
    capture reghdfe science eclipses_binary volcanoes_binary if century<=`c', absorb(country century) cluster(country#century)
    if _rc == 0 & e(N) >= 40 {
        local century = -2000 + `c'*100
        qui eststo r_`c'
        if "${regs_to_plot}" == "(" {
            global regs_to_plot "${regs_to_plot} r_`c'"
            global myeqrename "${myeqrename} r_`c' = `century'"
        }
        else {
            global regs_to_plot "${regs_to_plot} \ r_`c'"
            global myeqrename "${myeqrename} r_`c' = `century'"
        }
    }
}

global regs_to_plot "${regs_to_plot} )"
#delimit ;
coefplot "${regs_to_plot}", 
    keep(eclipses_binary ) vertical legend(off) 
    levels(90)
    aseq    
    recast(line)
    lwidth(*2)
    ciopts(recast(rline) lpattern(dash))
    eqrename(${myeqrename})
    eqlabels(, angle(vertical))
    xlabel(, nolabels)
    yline(0);
#delimit cr
translate @Graph "${path_figures}/Eclipses_Science.pdf", name("Graph")

/* Repeat the analysis for religious occupations */
global regs_to_plot "("
global myeqrename ""
qui levelsof century, local(cen)
foreach c of local cen {
    capture reghdfe religious eclipses_binary volcanoes_binary if century<=`c', cluster(country#century) absorb(country century)
    if _rc == 0 & e(N) >= 40 {
        local century = -2000 + `c'*100
        qui eststo r_`c'
        if "${regs_to_plot}" == "(" {
            global regs_to_plot "${regs_to_plot} r_`c'"
            global myeqrename "${myeqrename} r_`c' = `century'"
        }
        else {
            global regs_to_plot "${regs_to_plot} \ r_`c'"
            global myeqrename "${myeqrename} r_`c' = `century'"
        }
    }
}
global regs_to_plot "${regs_to_plot} )"

#delimit ;
coefplot "${regs_to_plot}", 
    keep(eclipses_binary ) vertical legend(off) 
    levels(90)
    aseq    
    recast(line)
    lwidth(*2)
    ciopts(recast(rline) lpattern(dash))
    eqrename(${myeqrename})
    eqlabels(, angle(vertical))
    xlabel(, nolabels)
    yline(0);
#delimit cr
translate @Graph "${path_figures}/Eclipses_Religion.pdf", name("Graph")

/* 
    Binned scatter-plots for the effects of eclipses on scince.
    This command does not accept p-weights, we use a-weights instead.
*/
forval i=1/2 {
    binscatter science eclipses_binary [aw = weight_`i'], control(volcanoes_binary i.century) absorb(city) xtitle("Eclipses|X") ytitle("Science|X") lcolor(black) mcolor(black) nq(100)
    translate @Graph "${path_figures}/Science_binscatter_`i'.pdf", name("Graph") replace 
}

forval i=1/2 {
    capture drop ec_res
    capture drop sc_res
    * First, compute the residuals using reghdfe
    qui reghdfe science volcanoes_binary [pw=weight_`i'], absorb(city century) res
    qui predict sc_res, res
    qui reghdfe eclipses_binary volcanoes_binary [pw=weight_`i'], absorb(city century) res
    qui predict ec_res, res
    qui centile ec_res, c(10 90)
    qui local low = r(c_1)
    qui local high = r(c_2)
    binscatter sc_res ec_res [aw = weight_`i'] if ec_res > `low' & ec_res < `high', xtitle("Eclipses|X") ytitle("Science|X") lcolor(black) mcolor(black) nq(100)
    translate @Graph "${path_figures}/Science_binscatter_Limited_`i'.pdf", name("Graph") replace 
}
