********************************************************************************
* Summary Stats
********************************************************************************

include "$path_stata/2-EA_Preparation.do"
global vars_level v31 v30 v33 v66 v90 explanation

foreach v of varlist $vars_level {
    capture tab `v', gen(levels_`v'_)
}

qui estpost summ eclipses_log eclipses_lunar_log

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs replace label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
refcat(eclipses_log "&\multicolumn{4}{c}{Ethnographic Atlas} \\ \cmidrule(lr){2-5} \emph{Eclipses}", nolabel)
noobs collabels(none) nomtitle nonum plain
coeflabels(eclipses_log "\hspace{0.1cm} Solar eclipses (log)" eclipses_lunar_log "\hspace{0.1cm} Lunar eclipses (log)" );
#delimit cr

qui estpost summ levels_v31_* levels_v30_* 

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
noobs collabels(none) plain nomtitles
refcat(levels_v31_1 "\emph{Population density}" levels_v30_1 "\emph{Settlement pattern}", nolabel)
coeflabels(	levels_v31_1 "\hspace{0.1cm} Fewer than 50 p."
		levels_v31_2 "\hspace{0.1cm} 50--99 p."
		levels_v31_3 "\hspace{0.1cm} 100--199 p."
		levels_v31_4 "\hspace{0.1cm} 200-399 p."
		levels_v31_5 "\hspace{0.1cm} 400--1000 p."
                levels_v31_6 "\hspace{0.1cm} More than 1000 p."
                levels_v31_7 "\hspace{0.1cm} Towns with more than 5000 p."
                levels_v31_8 "\hspace{0.1cm} Cities with more than 50000 p."

		levels_v30_1 "\hspace{0.1cm} Fully migratory"
		levels_v30_2 "\hspace{0.1cm} Seminomadic"
		levels_v30_3 "\hspace{0.1cm} Semisedentary"
		levels_v30_4 "\hspace{0.1cm} Compact, impermanent settlements"
		levels_v30_5 "\hspace{0.1cm} Neighbourhoods"
		levels_v30_6 "\hspace{0.1cm} Hamlets"
		levels_v30_7 "\hspace{0.1cm} Nucleated villages"
		levels_v30_8 "\hspace{0.1cm} Complex settlements"
		
		
		);
#delimit cr
qui estpost summ levels_v33_* levels_v66_* 

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
noobs collabels(none) plain nomtitles
refcat(levels_v33_1 "\emph{Jurisdictional Hierarchy}" levels_v66_1 "\emph{Class Stratification}", nolabel)
coeflabels(	levels_v33_1 "\hspace{0.1cm} No levels"
		levels_v33_2 "\hspace{0.1cm} One level"
		levels_v33_3 "\hspace{0.1cm} Two levels"
		levels_v33_4 "\hspace{0.1cm} Three levels"
		levels_v33_5 "\hspace{0.1cm} Four levels"
		
		levels_v66_1 "\hspace{0.1cm} Absence among freemen"
		levels_v66_2 "\hspace{0.1cm} Wealth distinctions"
		levels_v66_3 "\hspace{0.1cm} Elite"
		levels_v66_4 "\hspace{0.1cm} Dual"
		levels_v66_5 "\hspace{0.1cm} Complex"
		
		
		);
#delimit cr

qui estpost summ levels_v90_*

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
noobs collabels(none) plain nomtitles
keep(levels_v90_2 levels_v90_3 levels_v90_4 levels_v90_5 levels_v90_6 levels_v90_7)
refcat(levels_v90_2 "\emph{Political Integration}", nolabel)
coeflabels(	levels_v90_2 "\hspace{0.1cm} Absence"
		levels_v90_3 "\hspace{0.1cm} Automous local comm."
		levels_v90_4 "\hspace{0.1cm} Peace groups"
		levels_v90_5 "\hspace{0.1cm} Minimal states"
		levels_v90_6 "\hspace{0.1cm} Little states"
		levels_v90_7 "\hspace{0.1cm} States"
		);
		
#delimit cr

qui estpost summ technology tasks strategy writing 

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
noobs collabels(none) plain nomtitles
keep(technology tasks strategy writing)
coeflabels(	
        technology "Technological level"
        tasks      "Tasks"
        strategy   "Games of strategy (0/1)"
        writing    "Writing (0/1)"
		);
#delimit cr

qui estpost summ levels_explanation_*

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
noobs collabels(none) plain nomtitles
keep(levels_explanation_1 levels_explanation_2 levels_explanation_3)
refcat(levels_explanation_1 "\emph{Eclipse Explanation}", nolabel)
coeflabels(	
        levels_explanation_1 "\hspace{0.1cm}No explanation"
        levels_explanation_2 "\hspace{0.1cm}Fancyful"
        levels_explanation_3 "\hspace{0.1cm}Detailed"
		);
#delimit cr

#delimit ;
preserve;
replace curious_related = (curious_related > 0 & !missing(curious_related));
replace religion_related = (religion_related > 0 & !missing(religion_related));
qui estpost summ $motifs $motifs_religion; 

esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
noobs collabels(none) plain nomtitles
refcat(eclipse_related "\emph{Words related to}", nolabel)
coeflabels(	eclipse_related         "\hspace{0.1cm} Eclipses"
                curious_related         "\hspace{0.1cm} Curious (0/1)"
                thinking_related        "\hspace{0.1cm} Thinking"
                calendar_related        "\hspace{0.1cm} Calendar"
                religion_related        "\hspace{0.1cm} Religion (0/1)"
                religious_related       "\hspace{0.1cm} Religious"
                pray_related            "\hspace{0.1cm} Pray"
                cloud_related           "\hspace{0.1cm} Cloud"
                lightning_related       "\hspace{0.1cm} Lightning"
                rock_related            "\hspace{0.1cm} Rock"
                sand_related            "\hspace{0.1cm} Sand"
                white_related           "\hspace{0.1cm} White"
                purple_related          "\hspace{0.1cm} Purple"
		
		);
#delimit cr
restore
include "$path_stata/3-Seshat_Preparation.do"

qui estpost summ eclipses density administrative_levels cc_hier cc_writing cc_money cc_infra cc_texts cc_cal

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
refcat(eclipses "&\multicolumn{4}{c}{Seshat} \\ \cmidrule(lr){2-5}%", nolabel)
noobs collabels(none) plain nomtitle nonum 
coeflabels(
                eclipses                "Solar eclipses (log)"
                density                 "Population density (log)"
                administrative_levels   "Administrative levels"
                cc_hier                 "Jurisdictional hierarchy"
                geometrical_measurements "Geometrical measurements"
                cc_writing              "Writing"
                cc_money                "Money"
                cc_infra                "Infrastructure"
                cc_texts                "Text types"
                cc_cal                  "Calendrical system"
                );
#delimit cr

qui estpost summ geometrical_measurements if geometrical_measurements > 0

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
refcat(eclipses "&\multicolumn{4}{c}{Seshat} \\ \cmidrule(lr){2-5}%", nolabel)
noobs collabels(none) plain nomtitle nonum 
coeflabels(
                geometrical_measurements "Geometrical measurements"
                );
#delimit cr

include "$path_stata/4-Ashraf_Galor_Preparation.do"

qui estpost summ lec ln_CEtech_ ln_CITtech_ ln_comm_ ln_indus_ ln_trans_ 

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
refcat(lec "&\multicolumn{4}{c}{Ashraf and Galor (2011)} \\ \cmidrule(lr){2-5}%", nolabel)
noobs collabels(none) plain nomtitle nonum 
coeflabels(
                lec "Solar eclipses (log)"
                ln_CEtech_ "General tech. index"
                ln_CITtech_ "Non-agri. tech. index"
                ln_comm_ "Communication tech."
                ln_indus_ "Industrial tech."
                ln_trans_ "Transportation tech."
                );
#delimit cr

include "$path_stata/5-Wikipedia_Preparation.do"

qui estpost summ eclipses_binary science religious

#delimit ;
esttab . using "${path_tables}/Summary_Statistics.tex",
fragment booktabs append label
cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))")
refcat(eclipses_binary "&\multicolumn{4}{c}{Wikidata} \\ \cmidrule(lr){2-5}%", nolabel)
noobs collabels(none) plain nomtitle nonum 
coeflabels(
                eclipses_binary "Solar eclipse (0/1)"
                science "Scientific occupation"
                religious "Religious occupation"               );
#delimit cr
